"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsstreamserverlessbodywithprompt import (
    CompletionsStreamServerlessBodyWithPrompt,
    CompletionsStreamServerlessBodyWithPromptTypedDict,
)
from .completionsstreamserverlessbodywithtokens import (
    CompletionsStreamServerlessBodyWithTokens,
    CompletionsStreamServerlessBodyWithTokensTypedDict,
)

ServerlessCompletionsStreamBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsStreamBodyTypedDict",
    Union[
        CompletionsStreamServerlessBodyWithPromptTypedDict,
        CompletionsStreamServerlessBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsStreamBody = TypeAliasType(
    "ServerlessCompletionsStreamBody",
    Union[
        CompletionsStreamServerlessBodyWithPrompt,
        CompletionsStreamServerlessBodyWithTokens,
    ],
)
