"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli_core.types import BaseModel


class ContainerImageGenerateSuccessTypedDict(TypedDict):
    image: bytes
    r"""The base64-encoded image."""


class ContainerImageGenerateSuccess(BaseModel):
    image: bytes
    r"""The base64-encoded image."""
