"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

InferenceDeploymentStatus = Literal[
    "UNKNOWN",
    "INITIALIZING",
    "RUNNING",
    "UPDATING",
    "SLEEPING",
    "AWAKING",
    "FAILED",
    "STOPPING",
    "TERMINATING",
    "TERMINATED",
    "READY",
]
r"""Status of inference deployment."""
