"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsdedicatedbodywithprompt import (
    CompletionsDedicatedBodyWithPrompt,
    CompletionsDedicatedBodyWithPromptTypedDict,
)
from .completionsdedicatedbodywithtokens import (
    CompletionsDedicatedBodyWithTokens,
    CompletionsDedicatedBodyWithTokensTypedDict,
)

DedicatedCompletionsBodyTypedDict = TypeAliasType(
    "DedicatedCompletionsBodyTypedDict",
    Union[
        CompletionsDedicatedBodyWithPromptTypedDict,
        CompletionsDedicatedBodyWithTokensTypedDict,
    ],
)


DedicatedCompletionsBody = TypeAliasType(
    "DedicatedCompletionsBody",
    Union[CompletionsDedicatedBodyWithPrompt, CompletionsDedicatedBodyWithTokens],
)
