"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing_extensions import TypedDict

from friendli_core.types import BaseModel


class EndpointSimplescaleConfigTypedDict(TypedDict):
    r"""Simple scaling options."""

    replicas: int


class EndpointSimplescaleConfig(BaseModel):
    r"""Simple scaling options."""

    replicas: int
