"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

import pydantic
from pydantic.functional_validators import AfterValidator
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel
from friendli_core.utils import validate_const

from .chatcompletebodytoolchoicefunction import (
    ChatCompleteBodyToolChoiceFunction,
    ChatCompleteBodyToolChoiceFunctionTypedDict,
)


class ChatCompleteBodyToolChoiceTypedDict(TypedDict):
    function: ChatCompleteBodyToolChoiceFunctionTypedDict
    type: Literal["function"]
    r"""The type of the tool. Currently, only `function` is supported."""


class ChatCompleteBodyToolChoice(BaseModel):
    function: ChatCompleteBodyToolChoiceFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
    r"""The type of the tool. Currently, only `function` is supported."""
