"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

InferenceDeploymentErrorCode = Literal[
    "WORKLOAD_INIT_UNKNOWN_ERROR",
    "WORKLOAD_INIT_SETTINGS_ERROR",
    "WORKLOAD_INIT_GRPC_ERROR",
    "WORKLOAD_INIT_MANIFEST_NOT_FOUND_ERROR",
    "WORKLOAD_INIT_MANIFEST_TYPE_ERROR",
    "WORKLOAD_INIT_DOWNLOAD_ERROR",
    "WORKLOAD_INIT_INVALID_TOKEN_ERROR",
    "WORKLOAD_INIT_CANNOT_ACCESS_REPO_ERROR",
    "WORKLOAD_INIT_HF_WANDB_API_ERROR",
    "WORKLOAD_INIT_INSUFFICIENT_DISK_ERROR",
    "INFERENCE_ENGINE_UNKNOWN_ERROR",
    "INFERENCE_ENGINE_INVALID_ARGUMENT_ERROR",
    "INFERENCE_ENGINE_MEMORY_ERROR",
    "INFERENCE_ENGINE_METERING_CLIENT_CONFIG_ERROR",
]
r"""ErrorCode type."""
