"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

from typing_extensions import TypedDict

from friendli_core.types import BaseModel

URLImageItemResponseFormat = Literal["url", "raw", "png", "jpeg", "jpg"]
r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""


class URLImageItemTypedDict(TypedDict):
    response_format: URLImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""
    seed: int
    r"""The seed used during image generation."""
    url: str
    r"""The URL of the generated image."""


class URLImageItem(BaseModel):
    response_format: URLImageItemResponseFormat
    r"""The format of the generated image. One of `url(default)`, `raw`, `png`, `jpeg`, and `jpg`."""

    seed: int
    r"""The seed used during image generation."""

    url: str
    r"""The URL of the generated image."""
