"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli_core.types import BaseModel

from .fileobject import FileObject, FileObjectTypedDict


class PlatformFilesListResultTypedDict(TypedDict):
    data: List[FileObjectTypedDict]


class PlatformFilesListResult(BaseModel):
    data: List[FileObject]
