"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Union

from typing_extensions import TypeAliasType

from .completionsserverlessbodywithprompt import (
    CompletionsServerlessBodyWithPrompt,
    CompletionsServerlessBodyWithPromptTypedDict,
)
from .completionsserverlessbodywithtokens import (
    CompletionsServerlessBodyWithTokens,
    CompletionsServerlessBodyWithTokensTypedDict,
)

ServerlessCompletionsBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsBodyTypedDict",
    Union[
        CompletionsServerlessBodyWithPromptTypedDict,
        CompletionsServerlessBodyWithTokensTypedDict,
    ],
)


ServerlessCompletionsBody = TypeAliasType(
    "ServerlessCompletionsBody",
    Union[CompletionsServerlessBodyWithPrompt, CompletionsServerlessBodyWithTokens],
)
