"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Any, Dict

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel


class ResponseFormatJSONSchemaSchemaTypedDict(TypedDict):
    schema_: Dict[str, Any]
    r"""The schema for the response format, described as a JSON Schema object."""


class ResponseFormatJSONSchemaSchema(BaseModel):
    schema_: Annotated[Dict[str, Any], pydantic.Field(alias="schema")]
    r"""The schema for the response format, described as a JSON Schema object."""
